@@ -1,7 +1,7 @@
 from twisted.internet import reactor
 from twisted.internet.protocol import ReconnectingClientFactory
 from twisted.protocols.basic import Int32StringReceiver
-from carbon.rules import getDestinations, loadRules
+from carbon.rules import loadRules, getDestinations, allDestinationServers
 from carbon.conf import settings
 from carbon import log
 
@@ -11,7 +11,7 @@ except ImportError:
   import pickle
 
 
-MAX_DATAPOINTS_PER_MESSAGE = 500
+MAX_DATAPOINTS_PER_MESSAGE = settings.MAX_DATAPOINTS_PER_MESSAGE
 RelayServers = []
 
 
@@ -52,7 +52,7 @@ class MetricPickleSender(Int32StringReceiver):
     while (not self.paused) and self.queue:
       datapoints = self.queue[:MAX_DATAPOINTS_PER_MESSAGE]
       self.queue = self.factory.queue = self.queue[MAX_DATAPOINTS_PER_MESSAGE:]
-      self.sendString( pickle.dumps(datapoints) )
+      self.sendString( pickle.dumps(datapoints, protocol=-1) )
       increment(self.sent, len(datapoints))
 
   def send(self, metric, datapoint):
@@ -66,7 +66,7 @@ class MetricPickleSender(Int32StringReceiver):
 
     else:
       datapoints = [ (metric, datapoint) ]
-      self.sendString( pickle.dumps(datapoints) )
+      self.sendString( pickle.dumps(datapoints, protocol=-1) )
       increment(self.sent)
 
 
@@ -76,8 +76,8 @@ class MetricSenderFactory(ReconnectingClientFactory):
 
   def __init__(self, host, port):
     self.host = host
-    self.port = port
-    self.remoteAddr = "%s:%d" % (host, port)
+    self.port = int(port)
+    self.remoteAddr = (host, self.port)
     self.queue = []
     # Define internal metric names
     self.destinationName = host.replace('.','_')
@@ -86,10 +86,10 @@ class MetricSenderFactory(ReconnectingClientFactory):
     self.queuedUntilConnected = 'destinations.%s.queuedUntilConnected' % self.destinationName
 
   def startedConnecting(self, connector):
-    log.relay('connecting to %s' % self.remoteAddr)
+    log.relay('connecting to %s:%d' % self.remoteAddr)
 
   def buildProtocol(self, addr):
-    log.relay('connection to %s established' % self.remoteAddr)
+    log.relay('connection to %s:%d established' % self.remoteAddr)
     self.connectedProtocol = MetricPickleSender()
     self.connectedProtocol.factory = self
     self.connectedProtocol.queue = self.queue
@@ -99,7 +99,7 @@ class MetricSenderFactory(ReconnectingClientFactory):
     increment(self.attemptedRelays)
 
     if len(self.queue) >= settings.MAX_QUEUE_SIZE:
-      log.relay('relay queue full for %s, dropping data' % self.remoteAddr)
+      log.relay('relay queue full for %s:%d, dropping data' % self.remoteAddr)
       increment(self.fullQueueDrops)
 
     elif self.connectedProtocol:
@@ -119,20 +119,14 @@ class MetricSenderFactory(ReconnectingClientFactory):
     log.relay("connection attempt to %s failed: %s" % (self.remoteAddr, reason.value))
 
 
-def startRelaying(servers, rulesFile):
+def startRelaying(rulesFile):
   assert not RelayServers, "Relaying already started"
   loadRules(rulesFile)
 
-  for server in servers:
-    if ':' in server:
-      host, port = server.split(':', 1)
-      port = int(port)
-    else:
-      host, port = server, 2004 # default cache pickle listener port
-
+  for (host, port) in allDestinationServers():
+    log.msg("Connecting to destination server %s:%d" % (host, port))
     factory = MetricSenderFactory(host, port)
     RelayServers.append(factory) # each factory represents a cache server
-
     reactor.connectTCP(host, port, factory)
 
   RelayServers.sort(key=lambda f: f.remoteAddr) # normalize the order
